import pandas as pd
import numpy as np
import argparse

# Set up argument parser
parser = argparse.ArgumentParser(description='Calculate shot noise current fluctuations from CSV data.')
parser.add_argument('input_file', type=str, help='Input CSV file containing shot noise data')
parser.add_argument('output_file', type=str, help='Output CSV file to save results')
args = parser.parse_args()

# Load the CSV file
try:
    data = pd.read_csv(args.input_file)
except FileNotFoundError:
    print(f"Error: The file {args.input_file} was not found. Please check the file path.")
    exit(1)
except Exception as e:
    print(f"Error reading {args.input_file}: {e}")
    exit(1)

data.columns = data.columns.str.strip()

# Map column names with units to internal names
data['R_f'] = data['R_f [Ohm]']
data['G_2'] = data['G_2 [1]']
data['V_HLEout'] = data['V_HLEout [V]']
data['V_HLEmonitor'] = data['V_HLEmonitor [V]']

# Assume V_HLEout is V_meter for this calculation
data['V_meter'] = data['V_HLEout']

# Calculate RMS current fluctuations
data['delta_i_squared'] = (data['V_meter'] * 10) / (100 * data['G_2'] * data['R_f'])**2

# Display results
print("Shot Noise Calculation:")
print(data[['R_f', 'G_2', 'V_meter', 'V_HLEmonitor', 'delta_i_squared']])
for index, row in data.iterrows():
    print(f"Row {index + 2}: Mean square current fluctuation = {row['delta_i_squared']:.2e} A^2")

# Save results to the specified output CSV
data.to_csv(args.output_file, index=False)
print(f"Results saved to {args.output_file}")
